; *******************************************************
; This file contains some macros for standard operations
; @author Ruediger Knoerig
; *******************************************************

; This macro inits the stackpointer to the end of the RAM
; It requires an additional temporary register "temp" in the
; upper half of the register file
.MACRO	INIT_SP	
	ldi	temp,HIGH(RAMEND);
	out	SPH,temp
	ldi	temp,LOW(RAMEND);
	out	SPL,temp	
.ENDMACRO

; This macro inits the serial port to a standard 8N1 data connection
; The first parameter gives the desired baud rate, the secound the clock rate.
; Again, a temporary register temp in the upper half of the register file
; will be required.
; @param 0 Baud rate
; @param 1 system clock rate
.MACRO	INIT_SER
	ldi		temp,HIGH(@1/(16*@0)-1) 	; setze Baudrate
   out		UBRRH,temp
   ldi		temp,LOW(@1/(16*@0)-1)
   out		UBRRL,temp
   ldi		temp,0b10000110	; 8 Datenbits, keine Paritt, 1 Stopbit
   out		UCSRC,temp
	ldi		temp,0b00011000
	out		UCSRB,temp
.ENDMACRO

; This macro inits the A/D converter to 8 Bit sampling on the given
; PortC port. The voltage reference is AVcc. Don't forget to activate the ADC with
; sbi ADCSR,ADSC!
; Again, a temporary register temp in the upper half of the register file
; will be required.
; @param 0 PortC input pin
; @param 1 Free-running mode 1=yes, 0=no
; @param 2 Interrupt enable 1=yes, 0=no
; @param	3 Prescaler (7=128/6=64/5=32/4=16/3=8/2=4/1=2)
.MACRO	INIT_AD_8u
	ldi 	temp,(0b01100000+@0);
	out 	ADMUX,temp;
	ldi	temp,((1 << ADEN) | @1*(1 << ADFR) | @2*(1 << ADIE))+@3;
	out	ADCSR,temp
.ENDMACRO
